/* Generated by Cython 0.15.1 on Mon Apr  9 11:44:51 2012 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#else

#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif

#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif

#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif

#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif

#if PY_VERSION_HEX < 0x02040000
  #define METH_COEXIST 0
  #define PyDict_CheckExact(op) (Py_TYPE(op) == &PyDict_Type)
  #define PyDict_Contains(d,o)   PySequence_Contains(d,o)
#endif

#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    PyNumber_Int(o)
  #define PyIndex_Check(o)     PyNumber_Check(o)
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
#endif

#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)

  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;

  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)

#endif

#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#endif

#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif

#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif

#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif

#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif

#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif

#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)

#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif

#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif

#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif

#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif

#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif

#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__misaka
#define __PYX_HAVE_API__misaka
#include "stdint.h"
#include "sundown/buffer.h"
#include "sundown/html.h"
#include "sundown/markdown.h"
#include "wrapper.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif


/* inline attribute */
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* unused attribute */
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || defined(__INTEL_COMPILER)
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif

typedef struct {PyObject **p; char *s; const long n; const char* encoding; const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/


/* Type Conversion Predeclarations */

#define __Pyx_PyBytes_FromUString(s) PyBytes_FromString((char*)s)
#define __Pyx_PyBytes_AsUString(s)   ((unsigned char*) PyBytes_AsString(s))

#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);

#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
    
static PyObject *__pyx_m;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "misaka.pyx",
};

/*--- Type declarations ---*/
struct __pyx_obj_6misaka_SmartyPants;
struct __pyx_obj_6misaka_BaseRenderer;
struct __pyx_obj_6misaka_HtmlTocRenderer;
struct __pyx_obj_6misaka_Markdown;
struct __pyx_obj_6misaka_HtmlRenderer;

/* "misaka.pyx":67
 * 
 * 
 * cdef class SmartyPants:             # <<<<<<<<<<<<<<
 *     """Smartypants is a post-processor for (X)HTML renderers and can be used
 *     standalone or as a mixin. It adds a methode named ``postprocess`` to the
 */
struct __pyx_obj_6misaka_SmartyPants {
  PyObject_HEAD
};


/* "misaka.pyx":116
 * 
 * 
 * cdef class BaseRenderer:             # <<<<<<<<<<<<<<
 *     """The ``BaseRenderer`` is boilerplate code for creating your own renderers by
 *     sublassing `BaseRenderer`. It takes care of setting the callbacks and flags.
 */
struct __pyx_obj_6misaka_BaseRenderer {
  PyObject_HEAD
  struct sd_callbacks callbacks;
  struct renderopt options;
  int flags;
};


/* "misaka.pyx":170
 * 
 * 
 * cdef class HtmlTocRenderer(BaseRenderer):             # <<<<<<<<<<<<<<
 *     """The HTML table of contents renderer that's included in Sundown.
 * 
 */
struct __pyx_obj_6misaka_HtmlTocRenderer {
  struct __pyx_obj_6misaka_BaseRenderer __pyx_base;
};


/* "misaka.pyx":184
 * 
 * 
 * cdef class Markdown:             # <<<<<<<<<<<<<<
 *     """The Markdown parser.
 * 
 */
struct __pyx_obj_6misaka_Markdown {
  PyObject_HEAD
  struct sd_markdown *markdown;
  struct __pyx_obj_6misaka_BaseRenderer *renderer;
};


/* "misaka.pyx":154
 * 
 * 
 * cdef class HtmlRenderer(BaseRenderer):             # <<<<<<<<<<<<<<
 *     """The HTML renderer that's included in Sundown.
 * 
 */
struct __pyx_obj_6misaka_HtmlRenderer {
  struct __pyx_obj_6misaka_BaseRenderer __pyx_base;
};


#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif

#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name)           __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
  #define __Pyx_RefNannyFinishContext()           __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],     PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,     const char* function_name); /*proto*/

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

#include <string.h>

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static int __Pyx_check_binary_version(void);

static void __Pyx_AddTraceback(const char *funcname, int __pyx_clineno,
                               int __pyx_lineno, const char *__pyx_filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/

/* Module declarations from 'libc.stdint' */

/* Module declarations from 'sundown' */

/* Module declarations from 'wrapper' */

/* Module declarations from 'misaka' */
static PyTypeObject *__pyx_ptype_6misaka_SmartyPants = 0;
static PyTypeObject *__pyx_ptype_6misaka_BaseRenderer = 0;
static PyTypeObject *__pyx_ptype_6misaka_HtmlRenderer = 0;
static PyTypeObject *__pyx_ptype_6misaka_HtmlTocRenderer = 0;
static PyTypeObject *__pyx_ptype_6misaka_Markdown = 0;
#define __Pyx_MODULE_NAME "misaka"
int __pyx_module_is_main_misaka = 0;

/* Implementation of 'misaka' */
static PyObject *__pyx_builtin_ValueError;
static char __pyx_k_1[] = "UTF-8";
static char __pyx_k_3[] = "utf-8";
static char __pyx_k_4[] = "expected instance of BaseRenderer, %s found";
static char __pyx_k_6[] = "1.0.2";
static char __pyx_k_7[] = "EXT_NO_INTRA_EMPHASIS";
static char __pyx_k__html[] = "html";
static char __pyx_k__text[] = "text";
static char __pyx_k__flags[] = "flags";
static char __pyx_k__setup[] = "setup";
static char __pyx_k__encode[] = "encode";
static char __pyx_k__misaka[] = "misaka";
static char __pyx_k__render[] = "render";
static char __pyx_k__strict[] = "strict";
static char __pyx_k__HTML_TOC[] = "HTML_TOC";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____name__[] = "__name__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k__renderer[] = "renderer";
static char __pyx_k____class__[] = "__class__";
static char __pyx_k__EXT_TABLES[] = "EXT_TABLES";
static char __pyx_k__ValueError[] = "ValueError";
static char __pyx_k__extensions[] = "extensions";
static char __pyx_k__preprocess[] = "preprocess";
static char __pyx_k__HTML_ESCAPE[] = "HTML_ESCAPE";
static char __pyx_k____version__[] = "__version__";
static char __pyx_k__postprocess[] = "postprocess";
static char __pyx_k__EXT_AUTOLINK[] = "EXT_AUTOLINK";
static char __pyx_k__TABLE_HEADER[] = "TABLE_HEADER";
static char __pyx_k__render_flags[] = "render_flags";
static char __pyx_k__HTML_SAFELINK[] = "HTML_SAFELINK";
static char __pyx_k__HTML_TOC_TREE[] = "HTML_TOC_TREE";
static char __pyx_k__TABLE_ALIGN_C[] = "TABLE_ALIGN_C";
static char __pyx_k__TABLE_ALIGN_L[] = "TABLE_ALIGN_L";
static char __pyx_k__TABLE_ALIGN_R[] = "TABLE_ALIGN_R";
static char __pyx_k__HTML_HARD_WRAP[] = "HTML_HARD_WRAP";
static char __pyx_k__HTML_SKIP_HTML[] = "HTML_SKIP_HTML";
static char __pyx_k__HTML_USE_XHTML[] = "HTML_USE_XHTML";
static char __pyx_k__EXT_FENCED_CODE[] = "EXT_FENCED_CODE";
static char __pyx_k__EXT_SUPERSCRIPT[] = "EXT_SUPERSCRIPT";
static char __pyx_k__HTML_SKIP_LINKS[] = "HTML_SKIP_LINKS";
static char __pyx_k__HTML_SKIP_STYLE[] = "HTML_SKIP_STYLE";
static char __pyx_k__TABLE_ALIGNMASK[] = "TABLE_ALIGNMASK";
static char __pyx_k__HTML_EXPAND_TABS[] = "HTML_EXPAND_TABS";
static char __pyx_k__HTML_SKIP_IMAGES[] = "HTML_SKIP_IMAGES";
static char __pyx_k__HTML_SMARTYPANTS[] = "HTML_SMARTYPANTS";
static char __pyx_k__EXT_SPACE_HEADERS[] = "EXT_SPACE_HEADERS";
static char __pyx_k__EXT_STRIKETHROUGH[] = "EXT_STRIKETHROUGH";
static char __pyx_k__EXT_LAX_HTML_BLOCKS[] = "EXT_LAX_HTML_BLOCKS";
static PyObject *__pyx_kp_s_1;
static PyObject *__pyx_kp_s_4;
static PyObject *__pyx_kp_s_6;
static PyObject *__pyx_n_s_7;
static PyObject *__pyx_n_s__EXT_AUTOLINK;
static PyObject *__pyx_n_s__EXT_FENCED_CODE;
static PyObject *__pyx_n_s__EXT_LAX_HTML_BLOCKS;
static PyObject *__pyx_n_s__EXT_SPACE_HEADERS;
static PyObject *__pyx_n_s__EXT_STRIKETHROUGH;
static PyObject *__pyx_n_s__EXT_SUPERSCRIPT;
static PyObject *__pyx_n_s__EXT_TABLES;
static PyObject *__pyx_n_s__HTML_ESCAPE;
static PyObject *__pyx_n_s__HTML_EXPAND_TABS;
static PyObject *__pyx_n_s__HTML_HARD_WRAP;
static PyObject *__pyx_n_s__HTML_SAFELINK;
static PyObject *__pyx_n_s__HTML_SKIP_HTML;
static PyObject *__pyx_n_s__HTML_SKIP_IMAGES;
static PyObject *__pyx_n_s__HTML_SKIP_LINKS;
static PyObject *__pyx_n_s__HTML_SKIP_STYLE;
static PyObject *__pyx_n_s__HTML_SMARTYPANTS;
static PyObject *__pyx_n_s__HTML_TOC;
static PyObject *__pyx_n_s__HTML_TOC_TREE;
static PyObject *__pyx_n_s__HTML_USE_XHTML;
static PyObject *__pyx_n_s__TABLE_ALIGNMASK;
static PyObject *__pyx_n_s__TABLE_ALIGN_C;
static PyObject *__pyx_n_s__TABLE_ALIGN_L;
static PyObject *__pyx_n_s__TABLE_ALIGN_R;
static PyObject *__pyx_n_s__TABLE_HEADER;
static PyObject *__pyx_n_s__ValueError;
static PyObject *__pyx_n_s____class__;
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____name__;
static PyObject *__pyx_n_s____test__;
static PyObject *__pyx_n_s____version__;
static PyObject *__pyx_n_s__encode;
static PyObject *__pyx_n_s__extensions;
static PyObject *__pyx_n_s__flags;
static PyObject *__pyx_n_s__html;
static PyObject *__pyx_n_s__misaka;
static PyObject *__pyx_n_s__postprocess;
static PyObject *__pyx_n_s__preprocess;
static PyObject *__pyx_n_s__render;
static PyObject *__pyx_n_s__render_flags;
static PyObject *__pyx_n_s__renderer;
static PyObject *__pyx_n_s__setup;
static PyObject *__pyx_n_s__strict;
static PyObject *__pyx_n_s__text;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_16;
static PyObject *__pyx_int_32;
static PyObject *__pyx_int_64;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_256;
static PyObject *__pyx_int_512;
static PyObject *__pyx_int_1024;
static PyObject *__pyx_int_2048;
static PyObject *__pyx_k_tuple_2;
static PyObject *__pyx_k_tuple_5;

/* "misaka.pyx":43
 * 
 * 
 * def html(object text, unsigned int extensions=0, unsigned int render_flags=0):             # <<<<<<<<<<<<<<
 *     """Convert markdown text to (X)HTML.
 * 
 */

static PyObject *__pyx_pf_6misaka_html(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6misaka_html[] = "Convert markdown text to (X)HTML.\n\n    Returns a unicode string.\n\n    :param text: A byte or unicode string.\n    :param extensions: Enable additional Markdown extensions with the ``EXT_*`` constants.\n    :param render_flags: Adjust HTML rendering behaviour with the ``HTML_*`` constants.\n    ";
static PyMethodDef __pyx_mdef_6misaka_html = {__Pyx_NAMESTR("html"), (PyCFunction)__pyx_pf_6misaka_html, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_6misaka_html)};
static PyObject *__pyx_pf_6misaka_html(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_text = 0;
  unsigned int __pyx_v_extensions;
  unsigned int __pyx_v_render_flags;
  struct __pyx_obj_6misaka_BaseRenderer *__pyx_v_renderer = NULL;
  struct __pyx_obj_6misaka_Markdown *__pyx_v_markdown = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__text,&__pyx_n_s__extensions,&__pyx_n_s__render_flags,0};
  __Pyx_RefNannySetupContext("html");
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__text);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__extensions);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__render_flags);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, PyTuple_GET_SIZE(__pyx_args), "html") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_text = values[0];
    if (values[1]) {
      __pyx_v_extensions = __Pyx_PyInt_AsUnsignedInt(values[1]); if (unlikely((__pyx_v_extensions == (unsigned int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_extensions = ((unsigned int)0);
    }
    if (values[2]) {
      __pyx_v_render_flags = __Pyx_PyInt_AsUnsignedInt(values[2]); if (unlikely((__pyx_v_render_flags == (unsigned int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_render_flags = ((unsigned int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("html", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("misaka.html", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;

  /* "misaka.pyx":53
 *     """
 * 
 *     if render_flags & HTML_TOC_TREE:             # <<<<<<<<<<<<<<
 *         renderer = HtmlTocRenderer(render_flags)
 *     else:
 */
  __pyx_t_1 = PyLong_FromUnsignedLong(__pyx_v_render_flags); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__HTML_TOC_TREE); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_And(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "misaka.pyx":54
 * 
 *     if render_flags & HTML_TOC_TREE:
 *         renderer = HtmlTocRenderer(render_flags)             # <<<<<<<<<<<<<<
 *     else:
 *         renderer = HtmlRenderer(render_flags)
 */
    __pyx_t_3 = PyLong_FromUnsignedLong(__pyx_v_render_flags); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_6misaka_HtmlTocRenderer)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __pyx_v_renderer = ((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L6;
  }
  /*else*/ {

    /* "misaka.pyx":56
 *         renderer = HtmlTocRenderer(render_flags)
 *     else:
 *         renderer = HtmlRenderer(render_flags)             # <<<<<<<<<<<<<<
 * 
 *     markdown = Markdown(renderer, extensions)
 */
    __pyx_t_3 = PyLong_FromUnsignedLong(__pyx_v_render_flags); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_6misaka_HtmlRenderer)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __pyx_v_renderer = ((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L6:;

  /* "misaka.pyx":58
 *         renderer = HtmlRenderer(render_flags)
 * 
 *     markdown = Markdown(renderer, extensions)             # <<<<<<<<<<<<<<
 *     result = markdown.render(text)
 * 
 */
  __pyx_t_3 = PyLong_FromUnsignedLong(__pyx_v_extensions); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_INCREF(((PyObject *)__pyx_v_renderer));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_renderer));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_renderer));
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_6misaka_Markdown)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_markdown = ((struct __pyx_obj_6misaka_Markdown *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "misaka.pyx":59
 * 
 *     markdown = Markdown(renderer, extensions)
 *     result = markdown.render(text)             # <<<<<<<<<<<<<<
 * 
 *     if render_flags & HTML_SMARTYPANTS:
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_markdown), __pyx_n_s__render); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_INCREF(__pyx_v_text);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_text);
  __Pyx_GIVEREF(__pyx_v_text);
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "misaka.pyx":61
 *     result = markdown.render(text)
 * 
 *     if render_flags & HTML_SMARTYPANTS:             # <<<<<<<<<<<<<<
 *         result = SmartyPants().postprocess(result)
 * 
 */
  __pyx_t_1 = PyLong_FromUnsignedLong(__pyx_v_render_flags); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__HTML_SMARTYPANTS); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_And(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "misaka.pyx":62
 * 
 *     if render_flags & HTML_SMARTYPANTS:
 *         result = SmartyPants().postprocess(result)             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_6misaka_SmartyPants)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__postprocess); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_INCREF(__pyx_v_result);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    __pyx_t_1 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_v_result);
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "misaka.pyx":64
 *         result = SmartyPants().postprocess(result)
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("misaka.html", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_renderer);
  __Pyx_XDECREF((PyObject *)__pyx_v_markdown);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":91
 *            ``ve`` will be turned into ``&rsquo;s``, ``&rsquo;t``, and so on.
 *     """
 *     def postprocess(self, object text):             # <<<<<<<<<<<<<<
 *         """Process the input text.
 * 
 */

static PyObject *__pyx_pf_6misaka_11SmartyPants_postprocess(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static char __pyx_doc_6misaka_11SmartyPants_postprocess[] = "Process the input text.\n\n        Returns a unicode string.\n\n        :param text: A byte or unicode string.\n        ";
static PyObject *__pyx_pf_6misaka_11SmartyPants_postprocess(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_py_string = 0;
  char *__pyx_v_c_string;
  struct buf *__pyx_v_ob;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  char *__pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("postprocess");

  /* "misaka.pyx":100
 *         # Convert string
 *         cdef bytes py_string
 *         if hasattr(text, 'encode'):             # <<<<<<<<<<<<<<
 *             py_string = text.encode('UTF-8', 'strict')
 *         else:
 */
  __pyx_t_1 = ((PyObject *)__pyx_n_s__encode);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_HasAttr(__pyx_v_text, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "misaka.pyx":101
 *         cdef bytes py_string
 *         if hasattr(text, 'encode'):
 *             py_string = text.encode('UTF-8', 'strict')             # <<<<<<<<<<<<<<
 *         else:
 *             py_string = text
 */
    __pyx_t_1 = PyObject_GetAttr(__pyx_v_text, __pyx_n_s__encode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_k_tuple_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected bytes, got %.200s", Py_TYPE(__pyx_t_3)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_py_string = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "misaka.pyx":103
 *             py_string = text.encode('UTF-8', 'strict')
 *         else:
 *             py_string = text             # <<<<<<<<<<<<<<
 *         cdef char *c_string = py_string
 * 
 */
    if (!(likely(PyBytes_CheckExact(__pyx_v_text))||((__pyx_v_text) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected bytes, got %.200s", Py_TYPE(__pyx_v_text)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_INCREF(__pyx_v_text);
    __pyx_v_py_string = ((PyObject*)__pyx_v_text);
  }
  __pyx_L5:;

  /* "misaka.pyx":104
 *         else:
 *             py_string = text
 *         cdef char *c_string = py_string             # <<<<<<<<<<<<<<
 * 
 *         cdef sundown.buf *ob = sundown.bufnew(128)
 */
  __pyx_t_4 = PyBytes_AsString(((PyObject *)__pyx_v_py_string)); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_c_string = __pyx_t_4;

  /* "misaka.pyx":106
 *         cdef char *c_string = py_string
 * 
 *         cdef sundown.buf *ob = sundown.bufnew(128)             # <<<<<<<<<<<<<<
 *         sundown.sdhtml_smartypants(ob,
 *             <uint8_t *> c_string, len(c_string))
 */
  __pyx_v_ob = bufnew(128);

  /* "misaka.pyx":108
 *         cdef sundown.buf *ob = sundown.bufnew(128)
 *         sundown.sdhtml_smartypants(ob,
 *             <uint8_t *> c_string, len(c_string))             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_5 = strlen(__pyx_v_c_string); 
  sdhtml_smartypants(__pyx_v_ob, ((uint8_t *)__pyx_v_c_string), __pyx_t_5);

  /* "misaka.pyx":110
 *             <uint8_t *> c_string, len(c_string))
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return (<char *> ob.data)[:ob.size].decode('UTF-8', 'strict')
 *         finally:
 */
  /*try:*/ {

    /* "misaka.pyx":111
 * 
 *         try:
 *             return (<char *> ob.data)[:ob.size].decode('UTF-8', 'strict')             # <<<<<<<<<<<<<<
 *         finally:
 *             sundown.bufrelease(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = ((PyObject *)PyUnicode_Decode(((char *)__pyx_v_ob->data), __pyx_v_ob->size, __pyx_k_1, __pyx_k__strict)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L7;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __pyx_r = ((PyObject *)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L6;
  }

  /* "misaka.pyx":113
 *             return (<char *> ob.data)[:ob.size].decode('UTF-8', 'strict')
 *         finally:
 *             sundown.bufrelease(ob)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    int __pyx_why;
    PyObject *__pyx_exc_type, *__pyx_exc_value, *__pyx_exc_tb;
    int __pyx_exc_lineno;
    __pyx_exc_type = 0; __pyx_exc_value = 0; __pyx_exc_tb = 0; __pyx_exc_lineno = 0;
    __pyx_why = 0; goto __pyx_L8;
    __pyx_L6: __pyx_exc_type = 0; __pyx_exc_value = 0; __pyx_exc_tb = 0; __pyx_exc_lineno = 0;
    __pyx_why = 3; goto __pyx_L8;
    __pyx_L7: {
      __pyx_why = 4;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_ErrFetch(&__pyx_exc_type, &__pyx_exc_value, &__pyx_exc_tb);
      __pyx_exc_lineno = __pyx_lineno;
      goto __pyx_L8;
    }
    __pyx_L8:;
    bufrelease(__pyx_v_ob);
    switch (__pyx_why) {
      case 3: goto __pyx_L0;
      case 4: {
        __Pyx_ErrRestore(__pyx_exc_type, __pyx_exc_value, __pyx_exc_tb);
        __pyx_lineno = __pyx_exc_lineno;
        __pyx_exc_type = 0;
        __pyx_exc_value = 0;
        __pyx_exc_tb = 0;
        goto __pyx_L1_error;
      }
    }
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("misaka.SmartyPants.postprocess", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_py_string);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":129
 *     cdef readonly int flags
 * 
 *     def __cinit__(self, int flags=0):             # <<<<<<<<<<<<<<
 *         self.options.self = <void *> self
 *         self.flags = flags
 */

static int __pyx_pf_6misaka_12BaseRenderer___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pf_6misaka_12BaseRenderer___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_flags;
  void **__pyx_v_source;
  void **__pyx_v_dest;
  PyObject *__pyx_v_method_name = 0;
  long __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  const char * __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__flags,0};
  __Pyx_RefNannySetupContext("__cinit__");
  {
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__flags);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, PyTuple_GET_SIZE(__pyx_args), "__cinit__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_flags = __Pyx_PyInt_AsInt(values[0]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_flags = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("misaka.BaseRenderer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;

  /* "misaka.pyx":130
 * 
 *     def __cinit__(self, int flags=0):
 *         self.options.self = <void *> self             # <<<<<<<<<<<<<<
 *         self.flags = flags
 *         self.setup()
 */
  ((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_v_self)->options.self = ((void *)__pyx_v_self);

  /* "misaka.pyx":131
 *     def __cinit__(self, int flags=0):
 *         self.options.self = <void *> self
 *         self.flags = flags             # <<<<<<<<<<<<<<
 *         self.setup()
 * 
 */
  ((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_v_self)->flags = __pyx_v_flags;

  /* "misaka.pyx":132
 *         self.options.self = <void *> self
 *         self.flags = flags
 *         self.setup()             # <<<<<<<<<<<<<<
 * 
 *         # Set callbacks
 */
  __pyx_t_1 = PyObject_GetAttr(__pyx_v_self, __pyx_n_s__setup); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "misaka.pyx":135
 * 
 *         # Set callbacks
 *         cdef void **source = <void **> &wrapper.callback_funcs             # <<<<<<<<<<<<<<
 *         cdef void **dest = <void **> &self.callbacks
 * 
 */
  __pyx_v_source = ((void **)(&callback_funcs));

  /* "misaka.pyx":136
 *         # Set callbacks
 *         cdef void **source = <void **> &wrapper.callback_funcs
 *         cdef void **dest = <void **> &self.callbacks             # <<<<<<<<<<<<<<
 * 
 *         cdef unicode method_name
 */
  __pyx_v_dest = ((void **)(&((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_v_self)->callbacks));

  /* "misaka.pyx":139
 * 
 *         cdef unicode method_name
 *         for i from 0 <= i < <int> wrapper.method_count by 1:             # <<<<<<<<<<<<<<
 *             # In Python 3 ``wrapper.method_names[i]`` is a byte string.
 *             # This means hasattr can't find any method in the renderer, so
 */
  __pyx_t_3 = ((int)method_count);
  for (__pyx_v_i = 0; __pyx_v_i < __pyx_t_3; __pyx_v_i+=1) {

    /* "misaka.pyx":143
 *             # This means hasattr can't find any method in the renderer, so
 *             # ``wrapper.method_names[i]`` is converted to a normal string first.
 *             method_name = wrapper.method_names[i].decode('utf-8')             # <<<<<<<<<<<<<<
 *             if hasattr(self, method_name):
 *                 dest[i] = source[i]
 */
    __pyx_t_4 = (method_names[__pyx_v_i]);
    __pyx_t_2 = ((PyObject *)PyUnicode_Decode(__pyx_t_4, strlen(__pyx_t_4), __pyx_k_3, NULL)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    if (!(likely(PyUnicode_CheckExact(((PyObject *)__pyx_t_2)))||((((PyObject *)__pyx_t_2)) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(((PyObject *)__pyx_t_2))->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF(((PyObject *)__pyx_v_method_name));
    __pyx_v_method_name = ((PyObject*)__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

    /* "misaka.pyx":144
 *             # ``wrapper.method_names[i]`` is converted to a normal string first.
 *             method_name = wrapper.method_names[i].decode('utf-8')
 *             if hasattr(self, method_name):             # <<<<<<<<<<<<<<
 *                 dest[i] = source[i]
 * 
 */
    __pyx_t_5 = PyObject_HasAttr(__pyx_v_self, ((PyObject *)__pyx_v_method_name)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_5) {

      /* "misaka.pyx":145
 *             method_name = wrapper.method_names[i].decode('utf-8')
 *             if hasattr(self, method_name):
 *                 dest[i] = source[i]             # <<<<<<<<<<<<<<
 * 
 *     def setup(self):
 */
      (__pyx_v_dest[__pyx_v_i]) = (__pyx_v_source[__pyx_v_i]);
      goto __pyx_L8;
    }
    __pyx_L8:;
  }

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("misaka.BaseRenderer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_method_name);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":147
 *                 dest[i] = source[i]
 * 
 *     def setup(self):             # <<<<<<<<<<<<<<
 *         """A method that can be overridden by the renderer that sublasses ``BaseRenderer``.
 *         It's called everytime an instance of a renderer is created.
 */

static PyObject *__pyx_pf_6misaka_12BaseRenderer_1setup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6misaka_12BaseRenderer_1setup[] = "A method that can be overridden by the renderer that sublasses ``BaseRenderer``.\n        It's called everytime an instance of a renderer is created.\n        ";
static PyObject *__pyx_pf_6misaka_12BaseRenderer_1setup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setup");

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":127
 * 
 *     #: Read-only render flags
 *     cdef readonly int flags             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int flags=0):
 */

static PyObject *__pyx_pf_6misaka_12BaseRenderer_5flags___get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pf_6misaka_12BaseRenderer_5flags___get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__");
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_v_self)->flags); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("misaka.BaseRenderer.flags.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":162
 *     :param flags: Adjust HTML rendering behaviour with the ``HTML_*`` constants.
 *     """
 *     def setup(self):             # <<<<<<<<<<<<<<
 *         self.options.html.flags = self.flags
 *         sundown.sdhtml_renderer(
 */

static PyObject *__pyx_pf_6misaka_12HtmlRenderer_setup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pf_6misaka_12HtmlRenderer_setup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setup");

  /* "misaka.pyx":163
 *     """
 *     def setup(self):
 *         self.options.html.flags = self.flags             # <<<<<<<<<<<<<<
 *         sundown.sdhtml_renderer(
 *             &self.callbacks,
 */
  ((struct __pyx_obj_6misaka_HtmlRenderer *)__pyx_v_self)->__pyx_base.options.html.flags = ((struct __pyx_obj_6misaka_HtmlRenderer *)__pyx_v_self)->__pyx_base.flags;

  /* "misaka.pyx":167
 *             &self.callbacks,
 *             &self.options.html,
 *             self.options.html.flags)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  sdhtml_renderer((&((struct __pyx_obj_6misaka_HtmlRenderer *)__pyx_v_self)->__pyx_base.callbacks), (&((struct __pyx_obj_6misaka_HtmlRenderer *)__pyx_v_self)->__pyx_base.options.html), ((struct __pyx_obj_6misaka_HtmlRenderer *)__pyx_v_self)->__pyx_base.options.html.flags);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":178
 *     :param flags: Adjust HTML rendering behaviour with the ``HTML_*`` constants.
 *     """
 *     def setup(self, int flags=0):             # <<<<<<<<<<<<<<
 *         sundown.sdhtml_toc_renderer(
 *             &self.callbacks,
 */

static PyObject *__pyx_pf_6misaka_15HtmlTocRenderer_setup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pf_6misaka_15HtmlTocRenderer_setup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__flags,0};
  __Pyx_RefNannySetupContext("setup");
  {
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__flags);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, PyTuple_GET_SIZE(__pyx_args), "setup") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_flags = __Pyx_PyInt_AsInt(values[0]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_flags = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setup", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("misaka.HtmlTocRenderer.setup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;

  /* "misaka.pyx":181
 *         sundown.sdhtml_toc_renderer(
 *             &self.callbacks,
 *             &self.options.html)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  sdhtml_toc_renderer((&((struct __pyx_obj_6misaka_HtmlTocRenderer *)__pyx_v_self)->__pyx_base.callbacks), (&((struct __pyx_obj_6misaka_HtmlTocRenderer *)__pyx_v_self)->__pyx_base.options.html));

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":194
 *     cdef BaseRenderer renderer
 * 
 *     def __cinit__(self, object renderer, int extensions=0):             # <<<<<<<<<<<<<<
 *         if not isinstance(renderer, BaseRenderer):
 *             raise ValueError('expected instance of BaseRenderer, %s found' % \
 */

static int __pyx_pf_6misaka_8Markdown___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pf_6misaka_8Markdown___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_renderer = 0;
  int __pyx_v_extensions;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__renderer,&__pyx_n_s__extensions,0};
  __Pyx_RefNannySetupContext("__cinit__");
  {
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__renderer);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__extensions);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, PyTuple_GET_SIZE(__pyx_args), "__cinit__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_renderer = values[0];
    if (values[1]) {
      __pyx_v_extensions = __Pyx_PyInt_AsInt(values[1]); if (unlikely((__pyx_v_extensions == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_extensions = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("misaka.Markdown.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;

  /* "misaka.pyx":195
 * 
 *     def __cinit__(self, object renderer, int extensions=0):
 *         if not isinstance(renderer, BaseRenderer):             # <<<<<<<<<<<<<<
 *             raise ValueError('expected instance of BaseRenderer, %s found' % \
 *                 renderer.__class__.__name__)
 */
  __pyx_t_1 = ((PyObject *)((PyObject*)__pyx_ptype_6misaka_BaseRenderer));
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_renderer, __pyx_t_1); 
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "misaka.pyx":197
 *         if not isinstance(renderer, BaseRenderer):
 *             raise ValueError('expected instance of BaseRenderer, %s found' % \
 *                 renderer.__class__.__name__)             # <<<<<<<<<<<<<<
 * 
 *         self.renderer = <BaseRenderer> renderer
 */
    __pyx_t_1 = PyObject_GetAttr(__pyx_v_renderer, __pyx_n_s____class__); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 197; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s____name__); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 197; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_4), __pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_1));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "misaka.pyx":199
 *                 renderer.__class__.__name__)
 * 
 *         self.renderer = <BaseRenderer> renderer             # <<<<<<<<<<<<<<
 *         self.markdown = sundown.sd_markdown_new(
 *             extensions, 16,
 */
  __Pyx_INCREF(((PyObject *)((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_v_renderer)));
  __Pyx_GIVEREF(__pyx_v_renderer);
  __Pyx_GOTREF(((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer);
  __Pyx_DECREF(((PyObject *)((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer));
  ((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer = ((struct __pyx_obj_6misaka_BaseRenderer *)__pyx_v_renderer);

  /* "misaka.pyx":200
 * 
 *         self.renderer = <BaseRenderer> renderer
 *         self.markdown = sundown.sd_markdown_new(             # <<<<<<<<<<<<<<
 *             extensions, 16,
 *             &self.renderer.callbacks,
 */
  ((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->markdown = sd_markdown_new(__pyx_v_extensions, 16, (&((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer->callbacks), ((struct html_renderopt *)(&((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer->options)));

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("misaka.Markdown.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":205
 *             <sundown.html_renderopt *> &self.renderer.options)
 * 
 *     def render(self, object text):             # <<<<<<<<<<<<<<
 *         """Render the Markdon text.
 * 
 */

static PyObject *__pyx_pf_6misaka_8Markdown_1render(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static char __pyx_doc_6misaka_8Markdown_1render[] = "Render the Markdon text.\n\n        Returns a unicode string.\n\n        :param text: A byte or unicode string.\n        ";
static PyObject *__pyx_pf_6misaka_8Markdown_1render(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_py_string = 0;
  char *__pyx_v_c_string;
  struct buf *__pyx_v_ib;
  struct buf *__pyx_v_ob;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  char *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("render");
  __Pyx_INCREF(__pyx_v_text);

  /* "misaka.pyx":212
 *         :param text: A byte or unicode string.
 *         """
 *         if hasattr(self.renderer, 'preprocess'):             # <<<<<<<<<<<<<<
 *             text = self.renderer.preprocess(text)
 * 
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject *)__pyx_n_s__preprocess);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyObject_HasAttr(__pyx_t_1, __pyx_t_2); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 212; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "misaka.pyx":213
 *         """
 *         if hasattr(self.renderer, 'preprocess'):
 *             text = self.renderer.preprocess(text)             # <<<<<<<<<<<<<<
 * 
 *         # Convert string
 */
    __pyx_t_2 = PyObject_GetAttr(((PyObject *)((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer), __pyx_n_s__preprocess); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __Pyx_INCREF(__pyx_v_text);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_text);
    __Pyx_GIVEREF(__pyx_v_text);
    __pyx_t_4 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_v_text);
    __pyx_v_text = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "misaka.pyx":217
 *         # Convert string
 *         cdef bytes py_string
 *         if hasattr(text, 'encode'):             # <<<<<<<<<<<<<<
 *             py_string = text.encode('UTF-8', 'strict')
 *         else:
 */
  __pyx_t_4 = ((PyObject *)__pyx_n_s__encode);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = PyObject_HasAttr(__pyx_v_text, __pyx_t_4); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 217; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "misaka.pyx":218
 *         cdef bytes py_string
 *         if hasattr(text, 'encode'):
 *             py_string = text.encode('UTF-8', 'strict')             # <<<<<<<<<<<<<<
 *         else:
 *             py_string = text
 */
    __pyx_t_4 = PyObject_GetAttr(__pyx_v_text, __pyx_n_s__encode); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_k_tuple_5), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected bytes, got %.200s", Py_TYPE(__pyx_t_1)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_py_string = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  /*else*/ {

    /* "misaka.pyx":220
 *             py_string = text.encode('UTF-8', 'strict')
 *         else:
 *             py_string = text             # <<<<<<<<<<<<<<
 *         cdef char *c_string = py_string
 * 
 */
    if (!(likely(PyBytes_CheckExact(__pyx_v_text))||((__pyx_v_text) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected bytes, got %.200s", Py_TYPE(__pyx_v_text)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_INCREF(__pyx_v_text);
    __pyx_v_py_string = ((PyObject*)__pyx_v_text);
  }
  __pyx_L6:;

  /* "misaka.pyx":221
 *         else:
 *             py_string = text
 *         cdef char *c_string = py_string             # <<<<<<<<<<<<<<
 * 
 *         # Buffers
 */
  __pyx_t_5 = PyBytes_AsString(((PyObject *)__pyx_v_py_string)); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 221; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_c_string = __pyx_t_5;

  /* "misaka.pyx":224
 * 
 *         # Buffers
 *         cdef sundown.buf *ib = sundown.bufnew(128)             # <<<<<<<<<<<<<<
 *         sundown.bufputs(ib, c_string)
 * 
 */
  __pyx_v_ib = bufnew(128);

  /* "misaka.pyx":225
 *         # Buffers
 *         cdef sundown.buf *ib = sundown.bufnew(128)
 *         sundown.bufputs(ib, c_string)             # <<<<<<<<<<<<<<
 * 
 *         cdef sundown.buf *ob = sundown.bufnew(128)
 */
  bufputs(__pyx_v_ib, __pyx_v_c_string);

  /* "misaka.pyx":227
 *         sundown.bufputs(ib, c_string)
 * 
 *         cdef sundown.buf *ob = sundown.bufnew(128)             # <<<<<<<<<<<<<<
 *         sundown.bufgrow(ob, <size_t> (ib.size * 1.4))
 * 
 */
  __pyx_v_ob = bufnew(128);

  /* "misaka.pyx":228
 * 
 *         cdef sundown.buf *ob = sundown.bufnew(128)
 *         sundown.bufgrow(ob, <size_t> (ib.size * 1.4))             # <<<<<<<<<<<<<<
 * 
 *         # Parse! And make a unicode string
 */
  bufgrow(__pyx_v_ob, ((size_t)(__pyx_v_ib->size * 1.4)));

  /* "misaka.pyx":231
 * 
 *         # Parse! And make a unicode string
 *         sundown.sd_markdown_render(ob, ib.data, ib.size, self.markdown)             # <<<<<<<<<<<<<<
 *         text = (<char *> ob.data)[:ob.size].decode('UTF-8', 'strict')
 * 
 */
  sd_markdown_render(__pyx_v_ob, __pyx_v_ib->data, __pyx_v_ib->size, ((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->markdown);

  /* "misaka.pyx":232
 *         # Parse! And make a unicode string
 *         sundown.sd_markdown_render(ob, ib.data, ib.size, self.markdown)
 *         text = (<char *> ob.data)[:ob.size].decode('UTF-8', 'strict')             # <<<<<<<<<<<<<<
 * 
 *         if hasattr(self.renderer, 'postprocess'):
 */
  __pyx_t_1 = ((PyObject *)PyUnicode_Decode(((char *)__pyx_v_ob->data), __pyx_v_ob->size, __pyx_k_1, __pyx_k__strict)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __Pyx_DECREF(__pyx_v_text);
  __pyx_v_text = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "misaka.pyx":234
 *         text = (<char *> ob.data)[:ob.size].decode('UTF-8', 'strict')
 * 
 *         if hasattr(self.renderer, 'postprocess'):             # <<<<<<<<<<<<<<
 *             text = self.renderer.postprocess(text)
 * 
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = ((PyObject *)__pyx_n_s__postprocess);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = PyObject_HasAttr(__pyx_t_1, __pyx_t_4); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "misaka.pyx":235
 * 
 *         if hasattr(self.renderer, 'postprocess'):
 *             text = self.renderer.postprocess(text)             # <<<<<<<<<<<<<<
 * 
 *         # Return a string and release buffers
 */
    __pyx_t_4 = PyObject_GetAttr(((PyObject *)((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->renderer), __pyx_n_s__postprocess); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __Pyx_INCREF(__pyx_v_text);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_text);
    __Pyx_GIVEREF(__pyx_v_text);
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_v_text);
    __pyx_v_text = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "misaka.pyx":238
 * 
 *         # Return a string and release buffers
 *         try:             # <<<<<<<<<<<<<<
 *             return text
 *         finally:
 */
  /*try:*/ {

    /* "misaka.pyx":239
 *         # Return a string and release buffers
 *         try:
 *             return text             # <<<<<<<<<<<<<<
 *         finally:
 *             sundown.bufrelease(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_text);
    __pyx_r = __pyx_v_text;
    goto __pyx_L8;
  }

  /* "misaka.pyx":241
 *             return text
 *         finally:
 *             sundown.bufrelease(ob)             # <<<<<<<<<<<<<<
 *             sundown.bufrelease(ib)
 * 
 */
  /*finally:*/ {
    int __pyx_why;
    __pyx_why = 0; goto __pyx_L10;
    __pyx_L8: __pyx_why = 3; goto __pyx_L10;
    __pyx_L10:;
    bufrelease(__pyx_v_ob);

    /* "misaka.pyx":242
 *         finally:
 *             sundown.bufrelease(ob)
 *             sundown.bufrelease(ib)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
    bufrelease(__pyx_v_ib);
    switch (__pyx_why) {
      case 3: goto __pyx_L0;
    }
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("misaka.Markdown.render", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_py_string);
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "misaka.pyx":244
 *             sundown.bufrelease(ib)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.markdown is not NULL:
 *             sundown.sd_markdown_free(self.markdown)
 */

static void __pyx_pf_6misaka_8Markdown_2__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pf_6misaka_8Markdown_2__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__");

  /* "misaka.pyx":245
 * 
 *     def __dealloc__(self):
 *         if self.markdown is not NULL:             # <<<<<<<<<<<<<<
 *             sundown.sd_markdown_free(self.markdown)
 */
  __pyx_t_1 = (((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->markdown != NULL);
  if (__pyx_t_1) {

    /* "misaka.pyx":246
 *     def __dealloc__(self):
 *         if self.markdown is not NULL:
 *             sundown.sd_markdown_free(self.markdown)             # <<<<<<<<<<<<<<
 */
    sd_markdown_free(((struct __pyx_obj_6misaka_Markdown *)__pyx_v_self)->markdown);
    goto __pyx_L5;
  }
  __pyx_L5:;

  __Pyx_RefNannyFinishContext();
}

static PyObject *__pyx_tp_new_6misaka_SmartyPants(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  return o;
}

static void __pyx_tp_dealloc_6misaka_SmartyPants(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_6misaka_SmartyPants[] = {
  {__Pyx_NAMESTR("postprocess"), (PyCFunction)__pyx_pf_6misaka_11SmartyPants_postprocess, METH_O, __Pyx_DOCSTR(__pyx_doc_6misaka_11SmartyPants_postprocess)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_SmartyPants = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_SmartyPants = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_SmartyPants = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_SmartyPants = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_6misaka_SmartyPants = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("misaka.SmartyPants"), /*tp_name*/
  sizeof(struct __pyx_obj_6misaka_SmartyPants), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6misaka_SmartyPants, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_SmartyPants, /*tp_as_number*/
  &__pyx_tp_as_sequence_SmartyPants, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_SmartyPants, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_SmartyPants, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("Smartypants is a post-processor for (X)HTML renderers and can be used\n    standalone or as a mixin. It adds a methode named ``postprocess`` to the\n    renderer.\n\n    ================================== ========\n    Source                             Result\n    ================================== ========\n    `'s` (s, t, m, d, re, ll, ve) [1]_ &rsquo;s\n    `--`                               &mdash;\n    `-`                                &ndash;\n    `...`                              &hellip;\n    `. . .`                            &hellip;\n    `(c)`                              &copy;\n    `(r)`                              &reg;\n    `(tm)`                             &trade;\n    `3/4`                              &frac34;\n    `1/2`                              &frac12;\n    `1/4`                              &frac14;\n    ================================== ========\n\n    .. [1] A ``'`` followed by a ``s``, ``t``, ``m``, ``d``, ``re``, ``ll`` or\n           ``ve`` will be turned into ``&rsquo;s``, ``&rsquo;t``, and so on.\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6misaka_SmartyPants, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6misaka_SmartyPants, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_6misaka_BaseRenderer(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  if (__pyx_pf_6misaka_12BaseRenderer___cinit__(o, a, k) < 0) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6misaka_BaseRenderer(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_6misaka_12BaseRenderer_flags(PyObject *o, void *x) {
  return __pyx_pf_6misaka_12BaseRenderer_5flags___get__(o);
}

static PyMethodDef __pyx_methods_6misaka_BaseRenderer[] = {
  {__Pyx_NAMESTR("setup"), (PyCFunction)__pyx_pf_6misaka_12BaseRenderer_1setup, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_6misaka_12BaseRenderer_1setup)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6misaka_BaseRenderer[] = {
  {(char *)"flags", __pyx_getprop_6misaka_12BaseRenderer_flags, 0, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_BaseRenderer = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_BaseRenderer = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_BaseRenderer = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_BaseRenderer = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_6misaka_BaseRenderer = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("misaka.BaseRenderer"), /*tp_name*/
  sizeof(struct __pyx_obj_6misaka_BaseRenderer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6misaka_BaseRenderer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_BaseRenderer, /*tp_as_number*/
  &__pyx_tp_as_sequence_BaseRenderer, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_BaseRenderer, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_BaseRenderer, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("The ``BaseRenderer`` is boilerplate code for creating your own renderers by\n    sublassing `BaseRenderer`. It takes care of setting the callbacks and flags.\n\n    :param flags: Available as a read-only, integer type attribute named ``self.flags``.\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6misaka_BaseRenderer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6misaka_BaseRenderer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6misaka_BaseRenderer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_6misaka_HtmlRenderer(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = __pyx_tp_new_6misaka_BaseRenderer(t, a, k);
  if (!o) return 0;
  return o;
}

static PyMethodDef __pyx_methods_6misaka_HtmlRenderer[] = {
  {__Pyx_NAMESTR("setup"), (PyCFunction)__pyx_pf_6misaka_12HtmlRenderer_setup, METH_NOARGS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_HtmlRenderer = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_HtmlRenderer = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_HtmlRenderer = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_HtmlRenderer = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_6misaka_HtmlRenderer = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("misaka.HtmlRenderer"), /*tp_name*/
  sizeof(struct __pyx_obj_6misaka_HtmlRenderer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6misaka_BaseRenderer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_HtmlRenderer, /*tp_as_number*/
  &__pyx_tp_as_sequence_HtmlRenderer, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_HtmlRenderer, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_HtmlRenderer, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("The HTML renderer that's included in Sundown.\n\n    Do you override the ``setup`` method when subclassing ``HtmlRenderer``. If\n    you do make sure to call parent class' ``setup`` method first.\n\n    :param flags: Adjust HTML rendering behaviour with the ``HTML_*`` constants.\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6misaka_HtmlRenderer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6misaka_HtmlRenderer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_6misaka_HtmlTocRenderer(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = __pyx_tp_new_6misaka_BaseRenderer(t, a, k);
  if (!o) return 0;
  return o;
}

static PyMethodDef __pyx_methods_6misaka_HtmlTocRenderer[] = {
  {__Pyx_NAMESTR("setup"), (PyCFunction)__pyx_pf_6misaka_15HtmlTocRenderer_setup, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_HtmlTocRenderer = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_HtmlTocRenderer = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_HtmlTocRenderer = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_HtmlTocRenderer = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_6misaka_HtmlTocRenderer = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("misaka.HtmlTocRenderer"), /*tp_name*/
  sizeof(struct __pyx_obj_6misaka_HtmlTocRenderer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6misaka_BaseRenderer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_HtmlTocRenderer, /*tp_as_number*/
  &__pyx_tp_as_sequence_HtmlTocRenderer, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_HtmlTocRenderer, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_HtmlTocRenderer, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("The HTML table of contents renderer that's included in Sundown.\n\n    Do you override the ``setup`` method when subclassing ``HtmlTocRenderer``.\n    If you do make sure to call parent class' ``setup`` method first.\n\n    :param flags: Adjust HTML rendering behaviour with the ``HTML_*`` constants.\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6misaka_HtmlTocRenderer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6misaka_HtmlTocRenderer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_6misaka_Markdown(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6misaka_Markdown *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_6misaka_Markdown *)o);
  p->renderer = ((struct __pyx_obj_6misaka_BaseRenderer *)Py_None); Py_INCREF(Py_None);
  if (__pyx_pf_6misaka_8Markdown___cinit__(o, a, k) < 0) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6misaka_Markdown(PyObject *o) {
  struct __pyx_obj_6misaka_Markdown *p = (struct __pyx_obj_6misaka_Markdown *)o;
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pf_6misaka_8Markdown_2__dealloc__(o);
    if (PyErr_Occurred()) PyErr_WriteUnraisable(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_XDECREF(((PyObject *)p->renderer));
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6misaka_Markdown(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6misaka_Markdown *p = (struct __pyx_obj_6misaka_Markdown *)o;
  if (p->renderer) {
    e = (*v)(((PyObject*)p->renderer), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6misaka_Markdown(PyObject *o) {
  struct __pyx_obj_6misaka_Markdown *p = (struct __pyx_obj_6misaka_Markdown *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->renderer);
  p->renderer = ((struct __pyx_obj_6misaka_BaseRenderer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6misaka_Markdown[] = {
  {__Pyx_NAMESTR("render"), (PyCFunction)__pyx_pf_6misaka_8Markdown_1render, METH_O, __Pyx_DOCSTR(__pyx_doc_6misaka_8Markdown_1render)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_Markdown = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_Markdown = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Markdown = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_Markdown = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_6misaka_Markdown = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("misaka.Markdown"), /*tp_name*/
  sizeof(struct __pyx_obj_6misaka_Markdown), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6misaka_Markdown, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_Markdown, /*tp_as_number*/
  &__pyx_tp_as_sequence_Markdown, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Markdown, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_Markdown, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("The Markdown parser.\n\n    :param renderer: An instance of ``BaseRenderer``.\n    :param extensions: Enable additional Markdown extensions with the ``EXT_*`` constants.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6misaka_Markdown, /*tp_traverse*/
  __pyx_tp_clear_6misaka_Markdown, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6misaka_Markdown, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6misaka_Markdown, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    __Pyx_NAMESTR("misaka"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
  {&__pyx_kp_s_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 0, 1, 0},
  {&__pyx_kp_s_6, __pyx_k_6, sizeof(__pyx_k_6), 0, 0, 1, 0},
  {&__pyx_n_s_7, __pyx_k_7, sizeof(__pyx_k_7), 0, 0, 1, 1},
  {&__pyx_n_s__EXT_AUTOLINK, __pyx_k__EXT_AUTOLINK, sizeof(__pyx_k__EXT_AUTOLINK), 0, 0, 1, 1},
  {&__pyx_n_s__EXT_FENCED_CODE, __pyx_k__EXT_FENCED_CODE, sizeof(__pyx_k__EXT_FENCED_CODE), 0, 0, 1, 1},
  {&__pyx_n_s__EXT_LAX_HTML_BLOCKS, __pyx_k__EXT_LAX_HTML_BLOCKS, sizeof(__pyx_k__EXT_LAX_HTML_BLOCKS), 0, 0, 1, 1},
  {&__pyx_n_s__EXT_SPACE_HEADERS, __pyx_k__EXT_SPACE_HEADERS, sizeof(__pyx_k__EXT_SPACE_HEADERS), 0, 0, 1, 1},
  {&__pyx_n_s__EXT_STRIKETHROUGH, __pyx_k__EXT_STRIKETHROUGH, sizeof(__pyx_k__EXT_STRIKETHROUGH), 0, 0, 1, 1},
  {&__pyx_n_s__EXT_SUPERSCRIPT, __pyx_k__EXT_SUPERSCRIPT, sizeof(__pyx_k__EXT_SUPERSCRIPT), 0, 0, 1, 1},
  {&__pyx_n_s__EXT_TABLES, __pyx_k__EXT_TABLES, sizeof(__pyx_k__EXT_TABLES), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_ESCAPE, __pyx_k__HTML_ESCAPE, sizeof(__pyx_k__HTML_ESCAPE), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_EXPAND_TABS, __pyx_k__HTML_EXPAND_TABS, sizeof(__pyx_k__HTML_EXPAND_TABS), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_HARD_WRAP, __pyx_k__HTML_HARD_WRAP, sizeof(__pyx_k__HTML_HARD_WRAP), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_SAFELINK, __pyx_k__HTML_SAFELINK, sizeof(__pyx_k__HTML_SAFELINK), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_SKIP_HTML, __pyx_k__HTML_SKIP_HTML, sizeof(__pyx_k__HTML_SKIP_HTML), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_SKIP_IMAGES, __pyx_k__HTML_SKIP_IMAGES, sizeof(__pyx_k__HTML_SKIP_IMAGES), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_SKIP_LINKS, __pyx_k__HTML_SKIP_LINKS, sizeof(__pyx_k__HTML_SKIP_LINKS), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_SKIP_STYLE, __pyx_k__HTML_SKIP_STYLE, sizeof(__pyx_k__HTML_SKIP_STYLE), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_SMARTYPANTS, __pyx_k__HTML_SMARTYPANTS, sizeof(__pyx_k__HTML_SMARTYPANTS), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_TOC, __pyx_k__HTML_TOC, sizeof(__pyx_k__HTML_TOC), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_TOC_TREE, __pyx_k__HTML_TOC_TREE, sizeof(__pyx_k__HTML_TOC_TREE), 0, 0, 1, 1},
  {&__pyx_n_s__HTML_USE_XHTML, __pyx_k__HTML_USE_XHTML, sizeof(__pyx_k__HTML_USE_XHTML), 0, 0, 1, 1},
  {&__pyx_n_s__TABLE_ALIGNMASK, __pyx_k__TABLE_ALIGNMASK, sizeof(__pyx_k__TABLE_ALIGNMASK), 0, 0, 1, 1},
  {&__pyx_n_s__TABLE_ALIGN_C, __pyx_k__TABLE_ALIGN_C, sizeof(__pyx_k__TABLE_ALIGN_C), 0, 0, 1, 1},
  {&__pyx_n_s__TABLE_ALIGN_L, __pyx_k__TABLE_ALIGN_L, sizeof(__pyx_k__TABLE_ALIGN_L), 0, 0, 1, 1},
  {&__pyx_n_s__TABLE_ALIGN_R, __pyx_k__TABLE_ALIGN_R, sizeof(__pyx_k__TABLE_ALIGN_R), 0, 0, 1, 1},
  {&__pyx_n_s__TABLE_HEADER, __pyx_k__TABLE_HEADER, sizeof(__pyx_k__TABLE_HEADER), 0, 0, 1, 1},
  {&__pyx_n_s__ValueError, __pyx_k__ValueError, sizeof(__pyx_k__ValueError), 0, 0, 1, 1},
  {&__pyx_n_s____class__, __pyx_k____class__, sizeof(__pyx_k____class__), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____name__, __pyx_k____name__, sizeof(__pyx_k____name__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s____version__, __pyx_k____version__, sizeof(__pyx_k____version__), 0, 0, 1, 1},
  {&__pyx_n_s__encode, __pyx_k__encode, sizeof(__pyx_k__encode), 0, 0, 1, 1},
  {&__pyx_n_s__extensions, __pyx_k__extensions, sizeof(__pyx_k__extensions), 0, 0, 1, 1},
  {&__pyx_n_s__flags, __pyx_k__flags, sizeof(__pyx_k__flags), 0, 0, 1, 1},
  {&__pyx_n_s__html, __pyx_k__html, sizeof(__pyx_k__html), 0, 0, 1, 1},
  {&__pyx_n_s__misaka, __pyx_k__misaka, sizeof(__pyx_k__misaka), 0, 0, 1, 1},
  {&__pyx_n_s__postprocess, __pyx_k__postprocess, sizeof(__pyx_k__postprocess), 0, 0, 1, 1},
  {&__pyx_n_s__preprocess, __pyx_k__preprocess, sizeof(__pyx_k__preprocess), 0, 0, 1, 1},
  {&__pyx_n_s__render, __pyx_k__render, sizeof(__pyx_k__render), 0, 0, 1, 1},
  {&__pyx_n_s__render_flags, __pyx_k__render_flags, sizeof(__pyx_k__render_flags), 0, 0, 1, 1},
  {&__pyx_n_s__renderer, __pyx_k__renderer, sizeof(__pyx_k__renderer), 0, 0, 1, 1},
  {&__pyx_n_s__setup, __pyx_k__setup, sizeof(__pyx_k__setup), 0, 0, 1, 1},
  {&__pyx_n_s__strict, __pyx_k__strict, sizeof(__pyx_k__strict), 0, 0, 1, 1},
  {&__pyx_n_s__text, __pyx_k__text, sizeof(__pyx_k__text), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ValueError = __Pyx_GetName(__pyx_b, __pyx_n_s__ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants");

  /* "misaka.pyx":101
 *         cdef bytes py_string
 *         if hasattr(text, 'encode'):
 *             py_string = text.encode('UTF-8', 'strict')             # <<<<<<<<<<<<<<
 *         else:
 *             py_string = text
 */
  __pyx_k_tuple_2 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_k_tuple_2));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_1));
  PyTuple_SET_ITEM(__pyx_k_tuple_2, 0, ((PyObject *)__pyx_kp_s_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__strict));
  PyTuple_SET_ITEM(__pyx_k_tuple_2, 1, ((PyObject *)__pyx_n_s__strict));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__strict));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_2));

  /* "misaka.pyx":218
 *         cdef bytes py_string
 *         if hasattr(text, 'encode'):
 *             py_string = text.encode('UTF-8', 'strict')             # <<<<<<<<<<<<<<
 *         else:
 *             py_string = text
 */
  __pyx_k_tuple_5 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_k_tuple_5));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_1));
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 0, ((PyObject *)__pyx_kp_s_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__strict));
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 1, ((PyObject *)__pyx_n_s__strict));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__strict));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_5));
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_16 = PyInt_FromLong(16); if (unlikely(!__pyx_int_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_32 = PyInt_FromLong(32); if (unlikely(!__pyx_int_32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_64 = PyInt_FromLong(64); if (unlikely(!__pyx_int_64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_256 = PyInt_FromLong(256); if (unlikely(!__pyx_int_256)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_512 = PyInt_FromLong(512); if (unlikely(!__pyx_int_512)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1024 = PyInt_FromLong(1024); if (unlikely(!__pyx_int_1024)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_2048 = PyInt_FromLong(2048); if (unlikely(!__pyx_int_2048)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initmisaka(void); /*proto*/
PyMODINIT_FUNC initmisaka(void)
#else
PyMODINIT_FUNC PyInit_misaka(void); /*proto*/
PyMODINIT_FUNC PyInit_misaka(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_misaka(void)");
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __pyx_binding_PyCFunctionType_USED
  if (__pyx_binding_PyCFunctionType_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("misaka"), __pyx_methods, 0, 0, PYTHON_API_VERSION);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (!__pyx_m) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  #if PY_MAJOR_VERSION < 3
  Py_INCREF(__pyx_m);
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME));
  if (!__pyx_b) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_module_is_main_misaka) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_6misaka_SmartyPants) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "SmartyPants", (PyObject *)&__pyx_type_6misaka_SmartyPants) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_6misaka_SmartyPants = &__pyx_type_6misaka_SmartyPants;
  if (PyType_Ready(&__pyx_type_6misaka_BaseRenderer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "BaseRenderer", (PyObject *)&__pyx_type_6misaka_BaseRenderer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_6misaka_BaseRenderer = &__pyx_type_6misaka_BaseRenderer;
  __pyx_type_6misaka_HtmlRenderer.tp_base = __pyx_ptype_6misaka_BaseRenderer;
  if (PyType_Ready(&__pyx_type_6misaka_HtmlRenderer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "HtmlRenderer", (PyObject *)&__pyx_type_6misaka_HtmlRenderer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_6misaka_HtmlRenderer = &__pyx_type_6misaka_HtmlRenderer;
  __pyx_type_6misaka_HtmlTocRenderer.tp_base = __pyx_ptype_6misaka_BaseRenderer;
  if (PyType_Ready(&__pyx_type_6misaka_HtmlTocRenderer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "HtmlTocRenderer", (PyObject *)&__pyx_type_6misaka_HtmlTocRenderer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_6misaka_HtmlTocRenderer = &__pyx_type_6misaka_HtmlTocRenderer;
  if (PyType_Ready(&__pyx_type_6misaka_Markdown) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Markdown", (PyObject *)&__pyx_type_6misaka_Markdown) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_6misaka_Markdown = &__pyx_type_6misaka_Markdown;
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "misaka.pyx":7
 * 
 * 
 * __version__ = '1.0.2'             # <<<<<<<<<<<<<<
 * 
 * # Markdown extensions
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____version__, ((PyObject *)__pyx_kp_s_6)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":10
 * 
 * # Markdown extensions
 * EXT_NO_INTRA_EMPHASIS = (1 << 0)             # <<<<<<<<<<<<<<
 * EXT_TABLES = (1 << 1)
 * EXT_FENCED_CODE = (1 << 2)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_7, __pyx_int_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 10; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":11
 * # Markdown extensions
 * EXT_NO_INTRA_EMPHASIS = (1 << 0)
 * EXT_TABLES = (1 << 1)             # <<<<<<<<<<<<<<
 * EXT_FENCED_CODE = (1 << 2)
 * EXT_AUTOLINK = (1 << 3)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__EXT_TABLES, __pyx_int_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":12
 * EXT_NO_INTRA_EMPHASIS = (1 << 0)
 * EXT_TABLES = (1 << 1)
 * EXT_FENCED_CODE = (1 << 2)             # <<<<<<<<<<<<<<
 * EXT_AUTOLINK = (1 << 3)
 * EXT_STRIKETHROUGH = (1 << 4)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__EXT_FENCED_CODE, __pyx_int_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":13
 * EXT_TABLES = (1 << 1)
 * EXT_FENCED_CODE = (1 << 2)
 * EXT_AUTOLINK = (1 << 3)             # <<<<<<<<<<<<<<
 * EXT_STRIKETHROUGH = (1 << 4)
 * EXT_LAX_HTML_BLOCKS = (1 << 5)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__EXT_AUTOLINK, __pyx_int_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":14
 * EXT_FENCED_CODE = (1 << 2)
 * EXT_AUTOLINK = (1 << 3)
 * EXT_STRIKETHROUGH = (1 << 4)             # <<<<<<<<<<<<<<
 * EXT_LAX_HTML_BLOCKS = (1 << 5)
 * EXT_SPACE_HEADERS = (1 << 6)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__EXT_STRIKETHROUGH, __pyx_int_16) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":15
 * EXT_AUTOLINK = (1 << 3)
 * EXT_STRIKETHROUGH = (1 << 4)
 * EXT_LAX_HTML_BLOCKS = (1 << 5)             # <<<<<<<<<<<<<<
 * EXT_SPACE_HEADERS = (1 << 6)
 * EXT_SUPERSCRIPT = (1 << 7)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__EXT_LAX_HTML_BLOCKS, __pyx_int_32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":16
 * EXT_STRIKETHROUGH = (1 << 4)
 * EXT_LAX_HTML_BLOCKS = (1 << 5)
 * EXT_SPACE_HEADERS = (1 << 6)             # <<<<<<<<<<<<<<
 * EXT_SUPERSCRIPT = (1 << 7)
 * 
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__EXT_SPACE_HEADERS, __pyx_int_64) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":17
 * EXT_LAX_HTML_BLOCKS = (1 << 5)
 * EXT_SPACE_HEADERS = (1 << 6)
 * EXT_SUPERSCRIPT = (1 << 7)             # <<<<<<<<<<<<<<
 * 
 * # HTML Render flags
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__EXT_SUPERSCRIPT, __pyx_int_128) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 17; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":20
 * 
 * # HTML Render flags
 * HTML_SKIP_HTML = (1 << 0)             # <<<<<<<<<<<<<<
 * HTML_SKIP_STYLE = (1 << 1)
 * HTML_SKIP_IMAGES = (1 << 2)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_SKIP_HTML, __pyx_int_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":21
 * # HTML Render flags
 * HTML_SKIP_HTML = (1 << 0)
 * HTML_SKIP_STYLE = (1 << 1)             # <<<<<<<<<<<<<<
 * HTML_SKIP_IMAGES = (1 << 2)
 * HTML_SKIP_LINKS = (1 << 3)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_SKIP_STYLE, __pyx_int_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":22
 * HTML_SKIP_HTML = (1 << 0)
 * HTML_SKIP_STYLE = (1 << 1)
 * HTML_SKIP_IMAGES = (1 << 2)             # <<<<<<<<<<<<<<
 * HTML_SKIP_LINKS = (1 << 3)
 * HTML_EXPAND_TABS = (1 << 4)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_SKIP_IMAGES, __pyx_int_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":23
 * HTML_SKIP_STYLE = (1 << 1)
 * HTML_SKIP_IMAGES = (1 << 2)
 * HTML_SKIP_LINKS = (1 << 3)             # <<<<<<<<<<<<<<
 * HTML_EXPAND_TABS = (1 << 4)
 * HTML_SAFELINK = (1 << 5)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_SKIP_LINKS, __pyx_int_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":24
 * HTML_SKIP_IMAGES = (1 << 2)
 * HTML_SKIP_LINKS = (1 << 3)
 * HTML_EXPAND_TABS = (1 << 4)             # <<<<<<<<<<<<<<
 * HTML_SAFELINK = (1 << 5)
 * HTML_TOC = (1 << 6)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_EXPAND_TABS, __pyx_int_16) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 24; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":25
 * HTML_SKIP_LINKS = (1 << 3)
 * HTML_EXPAND_TABS = (1 << 4)
 * HTML_SAFELINK = (1 << 5)             # <<<<<<<<<<<<<<
 * HTML_TOC = (1 << 6)
 * HTML_HARD_WRAP = (1 << 7)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_SAFELINK, __pyx_int_32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 25; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":26
 * HTML_EXPAND_TABS = (1 << 4)
 * HTML_SAFELINK = (1 << 5)
 * HTML_TOC = (1 << 6)             # <<<<<<<<<<<<<<
 * HTML_HARD_WRAP = (1 << 7)
 * HTML_USE_XHTML = (1 << 8)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_TOC, __pyx_int_64) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":27
 * HTML_SAFELINK = (1 << 5)
 * HTML_TOC = (1 << 6)
 * HTML_HARD_WRAP = (1 << 7)             # <<<<<<<<<<<<<<
 * HTML_USE_XHTML = (1 << 8)
 * HTML_ESCAPE = (1 << 9)
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_HARD_WRAP, __pyx_int_128) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 27; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":28
 * HTML_TOC = (1 << 6)
 * HTML_HARD_WRAP = (1 << 7)
 * HTML_USE_XHTML = (1 << 8)             # <<<<<<<<<<<<<<
 * HTML_ESCAPE = (1 << 9)
 * 
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_USE_XHTML, __pyx_int_256) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":29
 * HTML_HARD_WRAP = (1 << 7)
 * HTML_USE_XHTML = (1 << 8)
 * HTML_ESCAPE = (1 << 9)             # <<<<<<<<<<<<<<
 * 
 * # Extra HTML render flags - these are not from Sundown
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_ESCAPE, __pyx_int_512) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 29; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":32
 * 
 * # Extra HTML render flags - these are not from Sundown
 * HTML_SMARTYPANTS = (1 << 10)  # An extra flag to enable Smartypants             # <<<<<<<<<<<<<<
 * HTML_TOC_TREE = (1 << 11)  # Only render a table of contents tree
 * 
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_SMARTYPANTS, __pyx_int_1024) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":33
 * # Extra HTML render flags - these are not from Sundown
 * HTML_SMARTYPANTS = (1 << 10)  # An extra flag to enable Smartypants
 * HTML_TOC_TREE = (1 << 11)  # Only render a table of contents tree             # <<<<<<<<<<<<<<
 * 
 * # Other flags
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__HTML_TOC_TREE, __pyx_int_2048) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":36
 * 
 * # Other flags
 * TABLE_ALIGN_L = 1 # MKD_TABLE_ALIGN_L             # <<<<<<<<<<<<<<
 * TABLE_ALIGN_R = 2 # MKD_TABLE_ALIGN_R
 * TABLE_ALIGN_C = 3 # MKD_TABLE_ALIGN_CENTER
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__TABLE_ALIGN_L, __pyx_int_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":37
 * # Other flags
 * TABLE_ALIGN_L = 1 # MKD_TABLE_ALIGN_L
 * TABLE_ALIGN_R = 2 # MKD_TABLE_ALIGN_R             # <<<<<<<<<<<<<<
 * TABLE_ALIGN_C = 3 # MKD_TABLE_ALIGN_CENTER
 * TABLE_ALIGNMASK = 3 # MKD_TABLE_ALIGNMASK
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__TABLE_ALIGN_R, __pyx_int_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":38
 * TABLE_ALIGN_L = 1 # MKD_TABLE_ALIGN_L
 * TABLE_ALIGN_R = 2 # MKD_TABLE_ALIGN_R
 * TABLE_ALIGN_C = 3 # MKD_TABLE_ALIGN_CENTER             # <<<<<<<<<<<<<<
 * TABLE_ALIGNMASK = 3 # MKD_TABLE_ALIGNMASK
 * TABLE_HEADER = 4 # MKD_TABLE_HEADER
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__TABLE_ALIGN_C, __pyx_int_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":39
 * TABLE_ALIGN_R = 2 # MKD_TABLE_ALIGN_R
 * TABLE_ALIGN_C = 3 # MKD_TABLE_ALIGN_CENTER
 * TABLE_ALIGNMASK = 3 # MKD_TABLE_ALIGNMASK             # <<<<<<<<<<<<<<
 * TABLE_HEADER = 4 # MKD_TABLE_HEADER
 * 
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__TABLE_ALIGNMASK, __pyx_int_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":40
 * TABLE_ALIGN_C = 3 # MKD_TABLE_ALIGN_CENTER
 * TABLE_ALIGNMASK = 3 # MKD_TABLE_ALIGNMASK
 * TABLE_HEADER = 4 # MKD_TABLE_HEADER             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__TABLE_HEADER, __pyx_int_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "misaka.pyx":43
 * 
 * 
 * def html(object text, unsigned int extensions=0, unsigned int render_flags=0):             # <<<<<<<<<<<<<<
 *     """Convert markdown text to (X)HTML.
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_6misaka_html, NULL, __pyx_n_s__misaka); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__html, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "misaka.pyx":1
 * cimport sundown             # <<<<<<<<<<<<<<
 * cimport wrapper
 * 
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____test__, ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    __Pyx_AddTraceback("init misaka", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init misaka");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */

#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name) {
    PyObject *result;
    result = PyObject_GetAttr(dict, name);
    if (!result) {
        if (dict != __pyx_b) {
            PyErr_Clear();
            result = PyObject_GetAttr(__pyx_b, name);
        }
        if (!result) {
            PyErr_SetObject(PyExc_NameError, name);
        }
    }
    return result;
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AS_STRING(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;

    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
        } else {
            #if PY_MAJOR_VERSION < 3
            if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key))) {
            #else
            if (unlikely(!PyUnicode_CheckExact(key)) && unlikely(!PyUnicode_Check(key))) {
            #endif
                goto invalid_keyword_type;
            } else {
                for (name = first_kw_arg; *name; name++) {
                    #if PY_MAJOR_VERSION >= 3
                    if (PyUnicode_GET_SIZE(**name) == PyUnicode_GET_SIZE(key) &&
                        PyUnicode_Compare(**name, key) == 0) break;
                    #else
                    if (PyString_GET_SIZE(**name) == PyString_GET_SIZE(key) &&
                        _PyString_Eq(**name, key)) break;
                    #endif
                }
                if (*name) {
                    values[name-argnames] = value;
                } else {
                    /* unexpected keyword found */
                    for (name=argnames; name != first_kw_arg; name++) {
                        if (**name == key) goto arg_passed_twice;
                        #if PY_MAJOR_VERSION >= 3
                        if (PyUnicode_GET_SIZE(**name) == PyUnicode_GET_SIZE(key) &&
                            PyUnicode_Compare(**name, key) == 0) goto arg_passed_twice;
                        #else
                        if (PyString_GET_SIZE(**name) == PyString_GET_SIZE(key) &&
                            _PyString_Eq(**name, key)) goto arg_passed_twice;
                        #endif
                    }
                    if (kwds2) {
                        if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                    } else {
                        goto invalid_keyword;
                    }
                }
            }
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, **name);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;

    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %"PY_FORMAT_SIZE_T"d positional argument%s (%"PY_FORMAT_SIZE_T"d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();

    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}

static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;

    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}


#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    /* cause is unused */
    Py_XINCREF(type);
    Py_XINCREF(value);
    Py_XINCREF(tb);
    /* First, check the traceback argument, replacing None with NULL. */
    if (tb == Py_None) {
        Py_DECREF(tb);
        tb = 0;
    }
    else if (tb != NULL && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto raise_error;
    }
    /* Next, replace a missing value with None */
    if (value == NULL) {
        value = Py_None;
        Py_INCREF(value);
    }
    #if PY_VERSION_HEX < 0x02050000
    if (!PyClass_Check(type))
    #else
    if (!PyType_Check(type))
    #endif
    {
        /* Raising an instance.  The value should be a dummy. */
        if (value != Py_None) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        /* Normalize to raise <class>, <instance> */
        Py_DECREF(value);
        value = type;
        #if PY_VERSION_HEX < 0x02050000
            if (PyInstance_Check(type)) {
                type = (PyObject*) ((PyInstanceObject*)type)->in_class;
                Py_INCREF(type);
            }
            else {
                type = 0;
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception must be an old-style class or instance");
                goto raise_error;
            }
        #else
            type = (PyObject*) Py_TYPE(type);
            Py_INCREF(type);
            if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception class must be a subclass of BaseException");
                goto raise_error;
            }
        #endif
    }

    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}

#else /* Python 3+ */

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;

    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (!PyExceptionClass_Check(type)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }

    if (cause) {
        PyObject *fixed_cause;
        if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        }
        else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        }
        else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        if (!value) {
            value = PyObject_CallObject(type, NULL);
        }
        PyException_SetCause(value, fixed_cause);
    }

    PyErr_SetObject(type, value);

    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }

bad:
    return;
}
#endif

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"

static void __Pyx_AddTraceback(const char *funcname, int __pyx_clineno,
                               int __pyx_lineno, const char *__pyx_filename) {
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    PyObject *py_globals = 0;
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;

    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(__pyx_filename);
    #else
    py_srcfile = PyUnicode_FromString(__pyx_filename);
    #endif
    if (!py_srcfile) goto bad;
    if (__pyx_clineno) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, __pyx_clineno);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, __pyx_clineno);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_code = PyCode_New(
        0,            /*int argcount,*/
        #if PY_MAJOR_VERSION >= 3
        0,            /*int kwonlyargcount,*/
        #endif
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple,  /*PyObject *consts,*/
        __pyx_empty_tuple,  /*PyObject *names,*/
        __pyx_empty_tuple,  /*PyObject *varnames,*/
        __pyx_empty_tuple,  /*PyObject *freevars,*/
        __pyx_empty_tuple,  /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        __pyx_lineno,   /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    if (!py_code) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = __pyx_lineno;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

/* Type Conversion Functions */

static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}

static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_VERSION_HEX < 0x03000000
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_VERSION_HEX < 0x03000000
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}

static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}

static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val == (unsigned PY_LONG_LONG)-1 && PyErr_Occurred())) {
       return (size_t)-1;
   } else if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
